@@ -27,6 +27,12 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     errorBox = new ErrorBox(this);
     errorBox->hide();
 
+    toolbar = new Toolbar(this);
+    toolbar->hide();
+
+    miniToolbar = new MinifiedToolbar(this);
+    miniToolbar->show();
+
     connect(webView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
     connect(webView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
     connect(webView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
@@ -34,6 +40,15 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     connect(webView->page()->networkAccessManager(), SIGNAL(finished(QNetworkReply*)), 
             this, SLOT(finishedRequest(QNetworkReply*)));
+
+    connect(miniToolbar->getShowToolbarButton(), SIGNAL(clicked()), this, SLOT(showToolbar()));
+    connect(toolbar->getHideToolbarButton(), SIGNAL(clicked()), this, SLOT(hideToolbar()));
+
+    connect(toolbar->getBackButton(), SIGNAL(clicked()), this->webView, SLOT(back()));
+    connect(toolbar->getFowardButton(), SIGNAL(clicked()), this->webView, SLOT(forward()));
+    connect(toolbar->getReloadButton(), SIGNAL(clicked()), this->webView, SLOT(reload()));
+
+    connect(toolbar, SIGNAL(urlChanged(QString)), this, SLOT(visitUrl(QString)));
 }
 
 MainWindow::~MainWindow()
@@ -50,6 +65,15 @@ void MainWindow::showLoading()
 void MainWindow::changeUrl(QUrl url)
 {
     currentUrl = url;
+    toolbar->getInputAddress()->setText( url.toString() );
+}
+
+void MainWindow::visitUrl(QString urlString)
+{
+    if (urlString.indexOf("http://") == -1)
+        urlString = "http://" + urlString;
+
+    webView->load(QUrl(urlString));
 }
 
 void MainWindow::hideLoading(bool success)
@@ -77,6 +101,8 @@ void MainWindow::adjustSizes()
     webView->setGeometry(0, 0, width(), height()); //webview cover the entire window
     loadingLabel->setGeometry( width()/2 - 45, height()/2 - 45, 90, 90); //put the label on the center
     errorBox->setGeometry( width()/2 - 150, height()/2 - 75, 300, 150); //put the error box on the center
+    toolbar->setGeometry( 0, height() - 38, width(), 38 );
+    miniToolbar->setGeometry( 0, height() - 38, 30, 38 );
 }
 
 void MainWindow::resizeEvent(QResizeEvent* event)
@@ -153,3 +179,15 @@ void MainWindow::disableWebkitAutoSize()
 {
     webView->page()->mainFrame()->evaluateJavaScript("document.body.style.WebkitTextSizeAdjust = 'auto'");
 }
+
+void MainWindow::showToolbar()
+{
+    toolbar->show();
+    miniToolbar->hide();
+}
+
+void MainWindow::hideToolbar()
+{
+    toolbar->hide();
+    miniToolbar->show();
+}
