@@ -4,6 +4,8 @@
 #include <QtGui/QMainWindow>
 #include "webview.h"
 #include "errorbox.h"
+#include "toolbar.h"
+#include "minifiedtoolbar.h"
 
 #include <QLabel>
 
@@ -25,6 +27,8 @@ private:
     // mainWindow components
     QLabel* loadingLabel;
     ErrorBox* errorBox;
+    Toolbar* toolbar;
+    MinifiedToolbar* miniToolbar;
 
     QUrl currentUrl;
 
@@ -61,6 +65,13 @@ private slots:
 
     //request
     void finishedRequest(QNetworkReply* reply);
+
+    //toolbar visibility control
+    void showToolbar();
+    void hideToolbar();
+
+    //visit url
+    void visitUrl(QString);
 };
 
 #endif // MAINWINDOW_H
